translate.convert.po2wordfast

Package translate :: Package convert :: Module po2wordfast |
[hide private]
[frames] | no frames]

# Module po2wordfast

source code

convert Gettext PO localization files to a Wordfast translation memory file

see: http://translate.sourceforge.net/wiki/toolkit/po2wordfast for examples and usage instructions

Classes | [hide private]
| po2wordfast
| wfmultifile
| WfOptionParser

Functions | [hide private]
convertpo(inputfile, outputfile, templatefile, sourcelanguage='en', targetlanguage=None) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Imports: os, po, wordfast, convert, wStringIO